@@ -3,14 +3,12 @@ use 5.010;
 use Moose::Role;
 with 'App::Base::Script::Common';
 
+our $VERSION = '0.07';    ## VERSION
+
 =head1 NAME
 
 App::Base::Daemon - A lazy person's tool for writing self-documenting, self-monitoring daemons
 
-=head1 VERSION
-
-This document describes App::Base version 0.05
-
 =head1 SYNOPSIS
 
     package App::Base::Daemon::example;
@@ -138,7 +136,7 @@ Run as specified user, note that it is only possible if daemon started as root
 
 =cut
 
-has user => ( is => 'ro' );
+has user => (is => 'ro');
 
 =head2 group
 
@@ -146,7 +144,7 @@ Run as specified group, note that it is only possible if daemon started as root
 
 =cut
 
-has group => ( is => 'ro' );
+has group => (is => 'ro');
 
 =head2 pid_file
 
@@ -183,7 +181,7 @@ around 'base_options' => sub {
     my $orig = shift;
     my $self = shift;
     return [
-        @{ $self->$orig },
+        @{$self->$orig},
         {
             name          => 'no-fork',
             documentation => "Do not detach and run in the background",
@@ -205,7 +203,8 @@ around 'base_options' => sub {
             name          => 'group',
             documentation => "Group to run as",
         },
-        {   name          => 'no-warn',
+        {
+            name          => 'no-warn',
             documentation => 'Do not produce warnings',
         },
     ];
@@ -217,7 +216,6 @@ around 'base_options' => sub {
 
 sub _signal_shutdown {
     my $self = shift;
-    my $sig  = shift;
     $self->handle_shutdown;
     exit 0;
 }
@@ -227,62 +225,51 @@ sub __run {
 
     my $pid;
     my $hot_reload = $ENV{APP_BASE_DAEMON_GEN}++ && $self->can_do_hot_reload;
-    unless ( $self->getOption('no-pid-file') or $hot_reload ) {
-        $pid = File::Flock::Tiny->trylock( $self->pid_file );
+    unless ($self->getOption('no-pid-file') or $hot_reload) {
+        $pid = File::Flock::Tiny->trylock($self->pid_file);
         unless ($pid) {
-            if ( $self->can_do_hot_reload ) {
-                chomp( my $pid = try { my $fh = path( $self->pid_file )->openr; <$fh>; } );
-                if ( $pid and kill USR2 => $pid ) {
+            if ($self->can_do_hot_reload) {
+                chomp(my $pid = try { my $fh = path($self->pid_file)->openr; <$fh>; });
+                if ($pid and kill USR2 => $pid) {
                     warn("Daemon is alredy running, initiated hot reload") unless $self->getOption('no-warn');
                     exit 0;
+                } else {
+                    $self->error("Neither could lock pid file nor send USR2 to already running daemon.");
                 }
-                else {
-                    $self->error(
-                        "Neither could lock pid file nor send USR2 to already running daemon.");
-                }
-            }
-            else {
-                die(  "Couldn't lock "
-                      . $self->pid_file
-                      . ". Is another copy of this daemon already running?" );
+            } else {
+                die("Couldn't lock " . $self->pid_file . ". Is another copy of this daemon already running?");
             }
         }
     }
 
-    $SIG{PIPE} = 'IGNORE';
-    foreach my $signal ( @{ $self->shutdown_signals } ) {
-        $SIG{$signal} = sub { App::Base::Daemon::_signal_shutdown( $self, @_ ) };
+    $SIG{PIPE} = 'IGNORE';    ## no critic (RequireLocalizedPunctuationVars)
+    foreach my $signal (@{$self->shutdown_signals}) {
+        $SIG{$signal} = sub { App::Base::Daemon::_signal_shutdown($self, @_) };    ## no critic (RequireLocalizedPunctuationVars)
     }
 
     # Daemonize unless specifically asked not to.
-    unless ( $self->getOption('no-fork') or $hot_reload ) {
+    unless ($self->getOption('no-fork') or $hot_reload) {
         my $child_pid = fork();
-        if ( !defined($child_pid) ) {
+        if (!defined($child_pid)) {
             die("Can't fork child process: $!");
-        }
-        elsif ( $child_pid == 0 ) {
+        } elsif ($child_pid == 0) {
             POSIX::setsid();
             my $grandchild_pid = fork();
-            if ( !defined($grandchild_pid) ) {
+            if (!defined($grandchild_pid)) {
                 die("Can't fork grandchild process: $!");
-            }
-            elsif ( $grandchild_pid != 0 ) {
+            } elsif ($grandchild_pid != 0) {
                 $pid->close if $pid;
                 exit 0;
-            }
-            else {
+            } else {
                 # close all STD* files, and redirect STD* to /dev/null
-                for ( 0 .. 2 ) {
+                for (0 .. 2) {
                     POSIX::close($_) unless $pid and $_ == $pid->fileno;
                 }
-                (         open( STDIN, '<', '/dev/null' )
-                      and open( STDOUT, '>', '/dev/null' )
-                      and open( STDERR, '>', '/dev/null' ) )
-                  or die "Couldn't open /dev/null: $!";
+                (open(STDIN, '<', '/dev/null') and open(STDOUT, '>', '/dev/null') and open(STDERR, '>', '/dev/null'))
+                    or die "Couldn't open /dev/null: $!";
             }
-        }
-        else {
-            waitpid( $child_pid, 0 );
+        } else {
+            waitpid($child_pid, 0);
             $pid->close if $pid;
             return $?;
         }
@@ -293,7 +280,7 @@ sub __run {
     $pid->write_pid if $pid;
 
     my $result;
-    try { $result = $self->daemon_run( @{ $self->parsed_args } ); }
+    try { $result = $self->daemon_run(@{$self->parsed_args}); }
     catch {
         $self->error($_);
     };
@@ -308,16 +295,16 @@ sub _set_user_and_group {
 
     my $user  = $self->getOption('user')  // $self->user;
     my $group = $self->getOption('group') // $self->group;
-    if ( $user or $group ) {
-        if ( $> == 0 ) {
-            my ( $uid, $gid ) = ( 0, 0 );
+    if ($user or $group) {
+        if ($> == 0) {
+            my ($uid, $gid) = (0, 0);
             if ($group) {
                 $gid = getgrnam($group) or $self->error("Can't find group $group");
             }
             if ($user) {
                 $uid = getpwnam($user) or $self->error("Can't find user $user");
             }
-            if ( $uid or $gid ) {
+            if ($uid or $gid) {
                 chown $uid, $gid, $self->pid_file;
             }
             if ($gid) {
@@ -326,8 +313,7 @@ sub _set_user_and_group {
             if ($uid) {
                 POSIX::setuid($uid);
             }
-        }
-        else {
+        } else {
             warn("Not running as root, can't setuid/setgid") unless $self->getOption('no-warn');
         }
     }
@@ -343,9 +329,9 @@ result in shutting down your daemon, use warn() instead.
 
 =cut
 
-sub error {
+sub error {    ## no critic (RequireArgUnpacking)
     my $self = shift;
-    warn( "Shutting down: " . join( ' ', @_ ) ) unless $self->getOption('no-warn');
+    warn("Shutting down: " . join(' ', @_)) unless $self->getOption('no-warn');
 
     $self->handle_shutdown();
     return exit(-1);
