@@ -3,6 +3,8 @@ use 5.010;
 use Moose::Role;
 with 'App::Base::Daemon';
 
+our $VERSION = '0.07';    ## VERSION
+
 =head1 NAME
 
 App::Base::Daemon::Supervisor - supervise daemon process
@@ -16,6 +18,7 @@ App::Base::Daemon::Supervisor - supervise daemon process
     sub documentation { return 'foo'; }
     sub options { ... }
     sub supervised_process {
+        my $self = shift;
         # the main daemon process
         while(1) {
             # check if supervisor is alive, exit otherwise
@@ -127,7 +130,7 @@ has supervisor_pipe => (
     writer => '_supervisor_pipe',
 );
 
-has _child_pid => ( is => 'rw' );
+has _child_pid => (is => 'rw');
 
 =head1 METHODS
 
@@ -145,7 +148,7 @@ sub ping_supervisor {
     my $pipe = $self->supervisor_pipe or $self->error("Supervisor pipe is not defined");
     say $pipe "ping";
     my $pong = <$pipe>;
-    unless ( defined $pong ) {
+    unless (defined $pong) {
         $self->error("Error reading from supervisor pipe: $!");
     }
     return;
@@ -195,28 +198,23 @@ sub daemon_run {
             $self->_supervisor_pipe($par);
             while (<$par>) {
                 chomp;
-                if ( $_ eq 'ping' ) {
+                if ($_ eq 'ping') {
                     say $par 'pong';
-                }
-                elsif ( $_ eq 'takeover' ) {
+                } elsif ($_ eq 'takeover') {
                     $self->_control_takeover;
                     say $par 'ok';
-                }
-                elsif ( $_ eq 'shutdown' ) {
+                } elsif ($_ eq 'shutdown') {
                     kill KILL => $pid;
                     close $par;
-                }
-                else {
+                } else {
                     warn("Received unknown command from the supervised process: $_") unless $self->getOption('no-warn');
                 }
             }
             my $kid = waitpid $pid, 0;
             warn("Supervised process $kid exited with status $?") unless $self->getOption('no-warn');
-        }
-        elsif ( not defined $pid ) {
+        } elsif (not defined $pid) {
             warn("Couldn't fork: $!") unless $self->getOption('no-warn');
-        }
-        else {
+        } else {
             local $SIG{USR2};
             $par->close;
             $chld->autoflush(1);
@@ -225,7 +223,7 @@ sub daemon_run {
             $self->supervised_process;
             exit 0;
         }
-        Time::HiRes::usleep( 1_000_000 * $self->delay_before_respawn );
+        Time::HiRes::usleep(1_000_000 * $self->delay_before_respawn);
     }
 
     # for critic
@@ -248,15 +246,15 @@ sub _set_hot_reload_handler {
         }
         warn("Received USR2, initiating hot reload") unless $self->getOption('no-warn');
         my $pid;
-        unless ( defined( $pid = fork ) ) {
+        unless (defined($pid = fork)) {
             warn("Could not fork, cancelling reload") unless $self->getOption('no-warn');
         }
         unless ($pid) {
-            exec( $ENV{APP_BASE_SCRIPT_EXE}, @{ $self->{orig_args} } )
-              or $self->error("Couldn't exec: $!");
+            exec($ENV{APP_BASE_SCRIPT_EXE}, @{$self->{orig_args}})
+                or $self->error("Couldn't exec: $!");
         }
         $upgrading = time;
-        if ( $SIG{ALRM} ) {
+        if ($SIG{ALRM}) {
             warn("ALRM handler is already defined!") unless $self->getOption('no-warn');
         }
         $SIG{ALRM} = sub {
@@ -267,9 +265,9 @@ sub _set_hot_reload_handler {
         alarm 60;
     };
     {
-        my $usr2 = POSIX::SigSet->new( POSIX::SIGUSR2() );
+        my $usr2 = POSIX::SigSet->new(POSIX::SIGUSR2());
         my $old  = POSIX::SigSet->new();
-        POSIX::sigprocmask( POSIX::SIG_UNBLOCK(), $usr2, $old );
+        POSIX::sigprocmask(POSIX::SIG_UNBLOCK(), $usr2, $old);
     }
 
     return;
@@ -284,19 +282,18 @@ sub _control_takeover {
     ## no critic (RequireLocalizedPunctuationVars)
 
     # if it is first generation, when pid file should be already locked in App::Base::Daemon
-    if ( $ENV{APP_BASE_DAEMON_GEN} > 1 and $ENV{APP_BASE_DAEMON_PID} != $$ ) {
+    if ($ENV{APP_BASE_DAEMON_GEN} > 1 and $ENV{APP_BASE_DAEMON_PID} != $$) {
         kill QUIT => $ENV{APP_BASE_DAEMON_PID};
-        if ( $self->getOption('no-pid-file') ) {
+        if ($self->getOption('no-pid-file')) {
 
             # we don't have pid file, so let's just poke it to death
             my $attempts = 14;
-            while ( kill( ( $attempts == 1 ? 'KILL' : 'ZERO' ) => $ENV{APP_BASE_DAEMON_PID} )
-                and $attempts-- )
+            while (kill(($attempts == 1 ? 'KILL' : 'ZERO') => $ENV{APP_BASE_DAEMON_PID})
+                and $attempts--)
             {
                 Time::HiRes::usleep(500_000);
             }
-        }
-        else {
+        } else {
             local $SIG{ALRM} = sub {
                 warn("Couldn't lock the file. Sending KILL to previous generation process") unless $self->getOption('no-warn');
             };
@@ -305,7 +302,7 @@ sub _control_takeover {
             # We may fail because two reasons:
             # a) previous process didn't exit and still holds the lock
             # b) new process was started and locked pid
-            $pid = try { File::Flock::Tiny->lock( $self->pid_file ) };
+            $pid = try { File::Flock::Tiny->lock($self->pid_file) };
             unless ($pid) {
 
                 # So let's try killing old process, if after that locking still will fail
@@ -313,7 +310,7 @@ sub _control_takeover {
                 kill KILL => $ENV{APP_BASE_DAEMON_PID};
                 $SIG{ALRM} = sub { $self->error("Still couldn't lock pid file, aborting") };
                 alarm 5;
-                $pid = File::Flock::Tiny->lock( $self->pid_file );
+                $pid = File::Flock::Tiny->lock($self->pid_file);
             }
             alarm 0;
             $pid->write_pid;
@@ -331,16 +328,19 @@ See L<App::Base::Daemon>
 
 sub handle_shutdown {
     my $self = shift;
-    if ( $self->is_supervisor ) {
+    if ($self->is_supervisor) {
         kill TERM => $self->_child_pid if $self->_child_pid;
-    }
-    else {
+    } else {
         $self->supervised_shutdown;
     }
 
     return;
 }
 
+=head2 DEMOLISH
+
+=cut
+
 sub DEMOLISH {
     my $self = shift;
     shutdown $self->supervisor_pipe, 2 if $self->supervisor_pipe;
