@@ -1,15 +1,15 @@
 package App::Base::Script::Common;
+use strict;
+use warnings;
 use 5.010;
 use Moose::Role;
 
+our $VERSION = '0.07';    ## VERSION
+
 =head1 NAME
 
 App::Base::Script::Common - Behaviors common to App::Base::Script and App::Base::Daemon
 
-=head1 VERSION
-
-This document describes App::Base version 0.05
-
 =head1 DESCRIPTION
 
 App::Base::Script::Common provides infrastructure that is common to the
@@ -151,15 +151,14 @@ sub BUILDARGS {
     $ENV{APP_BASE_SCRIPT_EXE} = abs_path($0);
     $arg_ref->{orig_args} = [@ARGV];
 
-    my $results = $class->_parse_arguments( \@ARGV );
-    if ( $results->{parse_result} ) {
+    my $results = $class->_parse_arguments(\@ARGV);
+    if ($results->{parse_result}) {
         $arg_ref->{_option_values} = $results->{option_values};
         $arg_ref->{parsed_args}    = $results->{parsed_args};
 
         # This exits.
-        $class->usage(0) if ( $results->{option_values}->{'help'} );
-    }
-    else {
+        $class->usage(0) if ($results->{option_values}->{'help'});
+    } else {
         # This exits.
         $class->usage(1);
     }
@@ -178,8 +177,8 @@ sub all_options {
     state $cache;
     my $class = ref($self) || $self;
     $cache->{$class} //=
-      [ map { App::Base::Script::Option->new($_) } @{ $self->options }, @{ $self->base_options } ];
-    $cache->{$class};
+        [map { App::Base::Script::Option->new($_) } @{$self->options}, @{$self->base_options}];
+    return $cache->{$class};
 }
 
 =head2 base_options
@@ -190,8 +189,7 @@ See BUILT-IN OPTIONS
 =cut
 
 sub base_options {
-    return [
-        {
+    return [{
             name          => 'help',
             documentation => 'Show this help information',
         },
@@ -206,7 +204,7 @@ Computes the maximum width of any of the switch (option) names.
 
 sub switch_name_width {
     my $self = shift;
-    return max( map { length( $_->display_name ) } @{ $self->all_options } );
+    return max(map { length($_->display_name) } @{$self->all_options});
 }
 
 =head2 switches
@@ -221,14 +219,13 @@ sub switches {
     my $col_width = $ENV{COLUMNS} || 76;
 
     my $max_option_length = $self->switch_name_width;
-    my $sw                = '[' x ( $max_option_length + 2 );
-    my $doc               = '[' x ( $col_width - $max_option_length - 1 );
+    my $sw                = '[' x ($max_option_length + 2);
+    my $doc               = '[' x ($col_width - $max_option_length - 1);
 
-    my @lines = map {
-        form { break => break_wrap }, "$sw $doc", '--' . $_->display_name, $_->show_documentation;
-    } ( sort { $a->name cmp $b->name } ( @{ $self->all_options } ) );
+    my @lines = map { form {break => break_wrap}, "$sw $doc", '--' . $_->display_name, $_->show_documentation; }
+        (sort { $a->name cmp $b->name } (@{$self->all_options}));
 
-    return join( '', @lines );
+    return join('', @lines);
 }
 
 =head2 cli_template
@@ -242,7 +239,7 @@ Defaults to "(program name) [options]", which is pretty standard Unix.
 
 sub cli_template {
     return "$0 [options] ";    # Override this if your script has a more complex command-line
-        # invocation template such as "$0[options] company_id [list1 [, list2 [, ...]]] "
+                               # invocation template such as "$0[options] company_id [list1 [, list2 [, ...]]] "
 }
 
 =head2 usage
@@ -252,19 +249,13 @@ Outputs a statement explaining the usage of the script, then exits.
 =cut
 
 sub usage {
-    my $self      = shift;
+    my $self = shift;
 
     my $col_width = $ENV{COLUMNS} || 76;
 
     my $format = '[' x $col_width;
 
-    my $message = join(
-        '', "\n",
-        form(
-            { break => break_wrap },
-            $format, [ "Usage: " . $self->cli_template, split( /[\r\n]/, $self->documentation ) ]
-        )
-    );
+    my $message = join('', "\n", form({break => break_wrap}, $format, ["Usage: " . $self->cli_template, split(/[\r\n]/, $self->documentation)]));
 
     $message .= "\nOptions:\n\n";
 
@@ -289,10 +280,9 @@ sub getOption {
     my $self   = shift;
     my $option = shift;
 
-    if ( exists( $self->_option_values->{$option} ) ) {
+    if (exists($self->_option_values->{$option})) {
         return $self->_option_values->{$option};
-    }
-    else {
+    } else {
         die "Unknown option $option";
     }
 
@@ -348,23 +338,21 @@ sub _parse_arguments {
     foreach my $option (@$options) {
         my $id   = $option->name;
         my $type = $option->option_type;
-        if ( $type eq 'string' ) {
+        if ($type eq 'string') {
             $id .= '=s';
-        }
-        elsif ( $type eq 'integer' ) {
+        } elsif ($type eq 'integer') {
             $id .= '=i';
-        }
-        elsif ( $type eq 'float' ) {
+        } elsif ($type eq 'float') {
             $id .= '=f';
         }
 
         my $scalar = $option->default;
-        $getopt_args{ $option->name } = \$scalar;
+        $getopt_args{$option->name} = \$scalar;
         $options_hash{$id} = \$scalar;
     }
 
     my $result = GetOptions(%options_hash);
-    my %option_values = map { $_ => ${ $getopt_args{$_} } } ( keys %getopt_args );
+    my %option_values = map { $_ => ${$getopt_args{$_}} } (keys %getopt_args);
     return {
         parse_result  => $result,
         option_values => \%option_values,
@@ -382,7 +370,7 @@ SUBCLASS METHODS), then exits.
 
 sub __error {
     my $self = shift;
-    warn( join " ", @_ );
+    warn(join " ", @_);
     exit(-1);
 }
 
@@ -476,14 +464,4 @@ The default value specified at registration time ("bar")
 
 Print a usage statement
 
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (C) 2010-2014 Binary.com
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
-
 =cut
