@@ -1,17 +1,17 @@
 package App::Base::Script::OnlyOne;
+use strict;
+use warnings;
 use Moose::Role;
 
 use Path::Tiny;
 use File::Flock::Tiny;
 
+our $VERSION = '0.07';    ## VERSION
+
 =head1 NAME
 
 App::Base::Script::OnlyOne - do not allow more than one instance running
 
-=head1 VERSION
-
-This document describes App::Base version 0.05
-
 =head1 SYNOPSIS
 
     use Moose;
@@ -44,15 +44,3 @@ no Moose::Role;
 1;
 
 __END__
-
-=head1 LICENSE AND COPYRIGHT
-
-Copyright (C) 2010-2014 Binary.com
-
-This program is free software; you can redistribute it and/or modify it
-under the terms of either: the GNU General Public License as published
-by the Free Software Foundation; or the Artistic License.
-
-See http://dev.perl.org/licenses/ for more information.
-
-=cut
